<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>AlbumInfoWidget</name>
    <message>
        <source>Title</source>
        <translation type="obsolete">Название</translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="obsolete">Описание</translation>
    </message>
    <message>
        <source>Creation time</source>
        <translation type="obsolete">Создан</translation>
    </message>
    <message>
        <source>Update time</source>
        <translation type="obsolete">Обновлен</translation>
    </message>
    <message>
        <location filename="../src/widgets/albuminfowidget.cpp" line="18"/>
        <source>Title:</source>
        <translation>Название:</translation>
    </message>
    <message>
        <location filename="../src/widgets/albuminfowidget.cpp" line="21"/>
        <source>Description:</source>
        <translation>Описание:</translation>
    </message>
    <message>
        <location filename="../src/widgets/albuminfowidget.cpp" line="24"/>
        <source>Created:</source>
        <translation>Создан:</translation>
    </message>
    <message>
        <location filename="../src/widgets/albuminfowidget.cpp" line="27"/>
        <source>Updated:</source>
        <translation>Обновлен:</translation>
    </message>
</context>
<context>
    <name>FilterFriendGender</name>
    <message>
        <location filename="../src/filter/filterfriendgender.cpp" line="41"/>
        <source>Male</source>
        <translation>Мужской</translation>
    </message>
    <message>
        <location filename="../src/filter/filterfriendgender.cpp" line="53"/>
        <source>Female</source>
        <translation>Женский</translation>
    </message>
</context>
<context>
    <name>FilterFriendOnline</name>
    <message>
        <location filename="../src/filter/filterfriendonline.cpp" line="29"/>
        <source>Online</source>
        <translation>В сети</translation>
    </message>
</context>
<context>
    <name>FilterMessageReaded</name>
    <message>
        <location filename="../src/filter/filtermessagereaded.cpp" line="31"/>
        <source>New</source>
        <translation>Новые</translation>
    </message>
</context>
<context>
    <name>FilterMessageType</name>
    <message>
        <location filename="../src/filter/filtermessagetype.cpp" line="72"/>
        <source>All messages</source>
        <translation>Все сообщения</translation>
    </message>
    <message>
        <location filename="../src/filter/filtermessagetype.cpp" line="76"/>
        <source>Inbox</source>
        <translation>Входящие</translation>
    </message>
    <message>
        <location filename="../src/filter/filtermessagetype.cpp" line="81"/>
        <source>Sent</source>
        <translation>Отправленные</translation>
    </message>
    <message>
        <location filename="../src/filter/filtermessagetype.cpp" line="85"/>
        <source>Drafts</source>
        <translation>Черновики</translation>
    </message>
</context>
<context>
    <name>Friend</name>
    <message>
        <location filename="../src/datatypes/friend.cpp" line="145"/>
        <source>Unknown</source>
        <translation>Неизвестный</translation>
    </message>
</context>
<context>
    <name>ImageBrowserPanel</name>
    <message>
        <location filename="../src/panels/imagebrowserpanel.ui" line="20"/>
        <source>Form</source>
        <translation>Панель изображений</translation>
    </message>
    <message>
        <source>People</source>
        <translation type="obsolete">Друзья</translation>
    </message>
    <message>
        <location filename="../src/panels/imagebrowserpanel.cpp" line="104"/>
        <location filename="../src/panels/imagebrowserpanel.cpp" line="472"/>
        <source>People (%1)</source>
        <translation>Друзья (%1)</translation>
    </message>
    <message>
        <source>News</source>
        <translation type="obsolete">Новости</translation>
    </message>
    <message>
        <location filename="../src/panels/imagebrowserpanel.cpp" line="113"/>
        <location filename="../src/panels/imagebrowserpanel.cpp" line="1000"/>
        <source>News (%1)</source>
        <translation>Обновления (%1)</translation>
    </message>
    <message>
        <source>Type a name...</source>
        <translation type="obsolete">Введите имя...</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/panels/imagebrowserpanel.cpp" line="326"/>
        <source>%1 photo(s)</source>
        <translation>
            <numerusform>%1 изображение</numerusform>
            <numerusform>%1 изображения</numerusform>
            <numerusform>%1 изображений</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/panels/imagebrowserpanel.cpp" line="328"/>
        <source> Updated: </source>
        <translation> Обновлен: </translation>
    </message>
    <message>
        <location filename="../src/panels/imagebrowserpanel.cpp" line="353"/>
        <source>Album(s):</source>
        <translation>Альбом(ы):</translation>
    </message>
    <message>
        <location filename="../src/panels/imagebrowserpanel.cpp" line="419"/>
        <source>Photo(s):</source>
        <translation>Изображения:</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/panels/imagebrowserpanel.cpp" line="430"/>
        <source>%1 photo(s):</source>
        <translation>
            <numerusform>%1 изображение:</numerusform>
            <numerusform>%1 изображения:</numerusform>
            <numerusform>%1 изображений:</numerusform>
        </translation>
    </message>
    <message>
        <source>No Friends</source>
        <translation type="obsolete">Нет друзей</translation>
    </message>
    <message>
        <source>Download friend list</source>
        <translation type="obsolete">Загрузка списка друзей</translation>
    </message>
    <message>
        <source>Online</source>
        <translation type="obsolete">В сети</translation>
    </message>
    <message>
        <location filename="../src/panels/imagebrowserpanel.cpp" line="321"/>
        <source>Untitled album</source>
        <translation>Безымянный альбом</translation>
    </message>
    <message>
        <location filename="../src/panels/imagebrowserpanel.cpp" line="524"/>
        <location filename="../src/panels/imagebrowserpanel.cpp" line="1084"/>
        <source>No albums</source>
        <translation>Нет альбомов</translation>
    </message>
    <message>
        <location filename="../src/panels/imagebrowserpanel.cpp" line="526"/>
        <location filename="../src/panels/imagebrowserpanel.cpp" line="1082"/>
        <source>Download albums</source>
        <translation>Загрузка списка альбомов</translation>
    </message>
    <message>
        <location filename="../src/panels/imagebrowserpanel.cpp" line="644"/>
        <source>No images</source>
        <translation>Нет изображений</translation>
    </message>
    <message>
        <location filename="../src/panels/imagebrowserpanel.cpp" line="646"/>
        <source>Download images</source>
        <translation>Загрузка изображений</translation>
    </message>
    <message>
        <location filename="../src/panels/imagebrowserpanel.cpp" line="933"/>
        <source>Error occured</source>
        <translation>Произошла ошибка</translation>
    </message>
    <message>
        <location filename="../src/panels/imagebrowserpanel.cpp" line="933"/>
        <source>Unknown window state</source>
        <translation>Неопределенное состояние окна</translation>
    </message>
</context>
<context>
    <name>MessageBrowser</name>
    <message>
        <location filename="../src/widgets/messagebrowser.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../src/widgets/messagebrowser.cpp" line="56"/>
        <source>Title:</source>
        <translation>Заголовок:</translation>
    </message>
    <message>
        <location filename="../src/widgets/messagebrowser.cpp" line="61"/>
        <source>From:</source>
        <translation>От кого:</translation>
    </message>
    <message>
        <location filename="../src/widgets/messagebrowser.cpp" line="185"/>
        <source>Date: </source>
        <translation>Дата: </translation>
    </message>
    <message>
        <location filename="../src/widgets/messagebrowser.cpp" line="189"/>
        <source>To: </source>
        <translation>Кому: </translation>
    </message>
    <message>
        <location filename="../src/widgets/messagebrowser.cpp" line="193"/>
        <location filename="../src/widgets/messagebrowser.cpp" line="196"/>
        <source>From: </source>
        <translation>От кого: </translation>
    </message>
    <message>
        <location filename="../src/widgets/messagebrowser.cpp" line="59"/>
        <source>Date:</source>
        <translation>Дата:</translation>
    </message>
    <message>
        <location filename="../src/widgets/messagebrowser.cpp" line="63"/>
        <source>To:</source>
        <translation>Кому:</translation>
    </message>
</context>
<context>
    <name>MessageBrowserPanel</name>
    <message>
        <location filename="../src/panels/messagebrowserpanel.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="obsolete">Тема</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="obsolete">Дата</translation>
    </message>
    <message>
        <location filename="../src/panels/messagebrowserpanel.cpp" line="88"/>
        <location filename="../src/panels/messagebrowserpanel.cpp" line="176"/>
        <source>Messages (%1)</source>
        <translation>Сообщения (%1)</translation>
    </message>
    <message>
        <source>News</source>
        <translation type="obsolete">Новости</translation>
    </message>
    <message>
        <location filename="../src/panels/messagebrowserpanel.cpp" line="98"/>
        <source>News (%1)</source>
        <translation>Обновления (%1)</translation>
    </message>
    <message>
        <location filename="../src/panels/messagebrowserpanel.cpp" line="371"/>
        <source>Error occured</source>
        <translation>Произошла ошибка</translation>
    </message>
    <message>
        <location filename="../src/panels/messagebrowserpanel.cpp" line="371"/>
        <source>Unknown window state</source>
        <translation>Неопределенное состояние окна</translation>
    </message>
</context>
<context>
    <name>MessageComposer</name>
    <message>
        <location filename="../src/widgets/messagecomposer.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../src/widgets/messagecomposer.ui" line="30"/>
        <source>Title:</source>
        <translation>Заголовок:</translation>
    </message>
    <message>
        <location filename="../src/widgets/messagecomposer.ui" line="40"/>
        <source>To:</source>
        <translation>Кому:</translation>
    </message>
    <message>
        <location filename="../src/widgets/messagecomposer.cpp" line="29"/>
        <source>Send</source>
        <translation>Отправить</translation>
    </message>
    <message>
        <location filename="../src/widgets/messagecomposer.cpp" line="33"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../src/widgets/messagecomposer.cpp" line="120"/>
        <source>Re: %1</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ProfileBrowser</name>
    <message>
        <location filename="../src/widgets/profilebrowser.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../src/widgets/profilebrowser.ui" line="37"/>
        <source>Photo</source>
        <translation>Изображение</translation>
    </message>
    <message>
        <location filename="../src/widgets/profilebrowser.ui" line="78"/>
        <location filename="../src/widgets/profilebrowser.ui" line="91"/>
        <source>TextLabel</source>
        <translation></translation>
    </message>
    <message>
        <source>First name:</source>
        <translation type="obsolete">Имя:</translation>
    </message>
    <message>
        <source>Nick:</source>
        <translation type="obsolete">Прозвище:</translation>
    </message>
    <message>
        <source>Last name:</source>
        <translation type="obsolete">Фамилия:</translation>
    </message>
    <message>
        <source>Gender:</source>
        <translation type="obsolete">Пол:</translation>
    </message>
    <message>
        <source>Birthday:</source>
        <translation type="obsolete">Дата рождения:</translation>
    </message>
    <message>
        <source>Mobile phone:</source>
        <translation type="obsolete">Мобильный телефон:</translation>
    </message>
    <message>
        <source>Home phone:</source>
        <translation type="obsolete">Стационарный телефон:</translation>
    </message>
    <message>
        <source>City:</source>
        <translation type="obsolete">Город:</translation>
    </message>
    <message>
        <source>Country:</source>
        <translation type="obsolete">Страна:</translation>
    </message>
    <message>
        <source>Places</source>
        <translation type="obsolete">Местоположение</translation>
    </message>
    <message>
        <location filename="../src/widgets/profilebrowser.cpp" line="114"/>
        <source>General</source>
        <translation>Основная информация</translation>
    </message>
    <message>
        <location filename="../src/widgets/profilebrowser.cpp" line="117"/>
        <source>Nickname: </source>
        <translation>Прозвище: </translation>
    </message>
    <message>
        <location filename="../src/widgets/profilebrowser.cpp" line="120"/>
        <source>Birthday: </source>
        <translation>День рождения: </translation>
    </message>
    <message>
        <location filename="../src/widgets/profilebrowser.cpp" line="124"/>
        <source>Gender: </source>
        <translation>Пол: </translation>
    </message>
    <message>
        <location filename="../src/widgets/profilebrowser.cpp" line="129"/>
        <source>Place</source>
        <translation>Местоположение</translation>
    </message>
    <message>
        <location filename="../src/widgets/profilebrowser.cpp" line="144"/>
        <source>Contacts</source>
        <translation>Контакты</translation>
    </message>
    <message>
        <location filename="../src/widgets/profilebrowser.h" line="87"/>
        <source>male</source>
        <translation>мужской</translation>
    </message>
    <message>
        <location filename="../src/widgets/profilebrowser.h" line="88"/>
        <source>female</source>
        <translation>женский</translation>
    </message>
</context>
<context>
    <name>ProfileBrowserPanel</name>
    <message>
        <location filename="../src/panels/profilebrowserpanel.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../src/panels/profilebrowserpanel.cpp" line="55"/>
        <source>Albums</source>
        <translation>Альбомы</translation>
    </message>
    <message>
        <location filename="../src/panels/profilebrowserpanel.cpp" line="64"/>
        <source>Messages</source>
        <translation>Сообщения</translation>
    </message>
    <message>
        <location filename="../src/panels/profilebrowserpanel.cpp" line="73"/>
        <source>Send message</source>
        <translation>Отправить сообщение</translation>
    </message>
    <message>
        <location filename="../src/panels/profilebrowserpanel.cpp" line="95"/>
        <source>News (%1)</source>
        <translation>Обновления (%1)</translation>
    </message>
    <message>
        <source>People</source>
        <translation type="obsolete">Друзья</translation>
    </message>
    <message>
        <location filename="../src/panels/profilebrowserpanel.cpp" line="86"/>
        <location filename="../src/panels/profilebrowserpanel.cpp" line="214"/>
        <source>People (%1)</source>
        <translation>Друзья (%1)</translation>
    </message>
    <message>
        <source>News</source>
        <translation type="obsolete">Новости</translation>
    </message>
    <message>
        <source>Type a name...</source>
        <translation type="obsolete">Введите имя...</translation>
    </message>
    <message>
        <source>No Friends</source>
        <translation type="obsolete">Нет друзей</translation>
    </message>
    <message>
        <source>Download friend list</source>
        <translation type="obsolete">Загрузка списка друзей</translation>
    </message>
    <message>
        <location filename="../src/panels/profilebrowserpanel.cpp" line="288"/>
        <source>Error occured</source>
        <translation>Произошла ошибка</translation>
    </message>
    <message>
        <location filename="../src/panels/profilebrowserpanel.cpp" line="288"/>
        <source>Unknown window state</source>
        <translation>Неопределенное состояние окна</translation>
    </message>
</context>
<context>
    <name>QAddComment</name>
    <message>
        <location filename="../src/widgets/qaddcomment.ui" line="14"/>
        <source>Add comment to image</source>
        <translation>Добавление комментария к изображению</translation>
    </message>
</context>
<context>
    <name>QDriversList</name>
    <message>
        <location filename="../src/widgets/qdriverslist.ui" line="14"/>
        <source>Form</source>
        <translation>Список драйверов</translation>
    </message>
</context>
<context>
    <name>QFriendDelegate</name>
    <message>
        <location filename="../src/widgets/friends/qfrienddelegate.cpp" line="86"/>
        <source>online</source>
        <translation>в сети</translation>
    </message>
</context>
<context>
    <name>QFriendListWidget</name>
    <message>
        <location filename="../src/widgets/friends/qfriendlistwidget.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../src/widgets/friends/qfriendlistwidget.cpp" line="21"/>
        <source>Type a name...</source>
        <translation>Введите имя...</translation>
    </message>
    <message>
        <location filename="../src/widgets/friends/qfriendlistwidget.cpp" line="56"/>
        <source>Me</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QImageViewer</name>
    <message>
        <location filename="../src/widgets/qimageviewer.cpp" line="95"/>
        <source>Comments</source>
        <translation>Комментарии</translation>
    </message>
    <message>
        <location filename="../src/widgets/qimageviewer.cpp" line="96"/>
        <source>Refresh comments</source>
        <translation>Обновить комментарии</translation>
    </message>
    <message>
        <location filename="../src/widgets/qimageviewer.cpp" line="98"/>
        <source>Add comment</source>
        <translation>Добавить комментарий</translation>
    </message>
    <message>
        <location filename="../src/widgets/qimageviewer.cpp" line="231"/>
        <source>Image Viewer</source>
        <translation>Программа просмотра изображений</translation>
    </message>
    <message>
        <location filename="../src/widgets/qimageviewer.cpp" line="232"/>
        <source>Cannot load %1.</source>
        <translation>Не удалось загрузить %1.</translation>
    </message>
    <message>
        <location filename="../src/widgets/qimageviewer.cpp" line="265"/>
        <source>Downloading image...</source>
        <translation>Загрузка изображения...</translation>
    </message>
</context>
<context>
    <name>QMessageListModel</name>
    <message>
        <location filename="../src/widgets/messages/qmessagelistmodel.cpp" line="81"/>
        <source>Title</source>
        <translation>Тема</translation>
    </message>
    <message>
        <location filename="../src/widgets/messages/qmessagelistmodel.cpp" line="83"/>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <location filename="../src/widgets/messages/qmessagelistmodel.cpp" line="85"/>
        <source>From/To</source>
        <translation>От/Кому</translation>
    </message>
</context>
<context>
    <name>QMessageListWidget</name>
    <message>
        <location filename="../src/widgets/messages/qmessagelistwidget.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <source>Type a name...</source>
        <translation type="obsolete">Введите имя...</translation>
    </message>
    <message>
        <location filename="../src/widgets/messages/qmessagelistwidget.cpp" line="22"/>
        <source>Type a title...</source>
        <translation>Введите тему сообщения...</translation>
    </message>
</context>
<context>
    <name>QPhotoUploader</name>
    <message>
        <location filename="../src/widgets/qphotouploader.ui" line="20"/>
        <source>Images upload manager</source>
        <translation>Загрузчик изображений</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.ui" line="97"/>
        <source>Total upload size:</source>
        <translation>Полный размер загрузки:</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.ui" line="126"/>
        <source>New album</source>
        <translation>Новый альбом</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.ui" line="145"/>
        <source>Add files</source>
        <translation>Добавить файлы</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.ui" line="187"/>
        <source>Upload</source>
        <translation>Загрузить</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.ui" line="194"/>
        <location filename="../src/widgets/qphotouploader.cpp" line="169"/>
        <source>Cancel</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.cpp" line="32"/>
        <source>Add description</source>
        <translation>Добавить описание</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.cpp" line="33"/>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.cpp" line="51"/>
        <source>No active accounts</source>
        <translation>Нет активных учётных записей</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/widgets/qphotouploader.cpp" line="114"/>
        <location filename="../src/widgets/qphotouploader.cpp" line="417"/>
        <source>%1 photo(s)</source>
        <translation>
            <numerusform>%1 изображение</numerusform>
            <numerusform>%1 изображения</numerusform>
            <numerusform>%1 изображений</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.cpp" line="117"/>
        <source>No avalible albums</source>
        <translation>Нет доступных альбомов</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.cpp" line="155"/>
        <source>bytes</source>
        <translation>байт</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.cpp" line="157"/>
        <source>Kbytes</source>
        <translation>Кбайт</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.cpp" line="158"/>
        <source>Mbytes</source>
        <translation>Мбайт</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.cpp" line="165"/>
        <source>Images</source>
        <translation>Изображения</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.cpp" line="166"/>
        <source>Look in:</source>
        <translation>Расположение:</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.cpp" line="167"/>
        <source>File name:</source>
        <translation>Имя файла:</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.cpp" line="168"/>
        <source>File types:</source>
        <translation>Типы файлов:</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.cpp" line="170"/>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.cpp" line="321"/>
        <source>Enter descripton:</source>
        <translation>Введить описание:</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.cpp" line="397"/>
        <source>Creating album</source>
        <translation>Создание альбома</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.cpp" line="398"/>
        <source>Enter name of the album:</source>
        <translation>Введите имя альбома:</translation>
    </message>
</context>
<context>
    <name>QTransport</name>
    <message>
        <location filename="../src/qtransport.cpp" line="251"/>
        <source>Caught an exception.</source>
        <translation>Произошла ошибка.</translation>
    </message>
    <message>
        <location filename="../src/qtransport.cpp" line="289"/>
        <location filename="../src/qtransport.cpp" line="1157"/>
        <source>Bad response from driver</source>
        <translation>Некорректный ответ от драйвера</translation>
    </message>
    <message>
        <location filename="../src/qtransport.cpp" line="351"/>
        <source>Unsupported method was called</source>
        <translation>Вызван неподдерживаемый метод</translation>
    </message>
    <message>
        <location filename="../src/qtransport.cpp" line="352"/>
        <source>This method didn&apos;t supported by selected driver</source>
        <translation>Метод не поддерживается выбранным драйвером</translation>
    </message>
    <message>
        <location filename="../src/qtransport.cpp" line="863"/>
        <source>The friend or album identificators are not equal</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/qtransport.cpp" line="864"/>
        <source>Incorrect identificators</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/qtransport.cpp" line="1117"/>
        <source>Can&apos;t read file to upload</source>
        <translation>Не удалось открыть отправляемый на сервис файл</translation>
    </message>
    <message>
        <location filename="../src/qtransport.cpp" line="1228"/>
        <source>QTransport::downloadPhotoLost() with nearest &lt; 0</source>
        <translation>QTransport::downloadPhotoLost() с параметром nearest &lt; 0</translation>
    </message>
    <message>
        <location filename="../src/qtransport.cpp" line="1229"/>
        <source>Wrong arguments of function</source>
        <translation>Неправильные аргументы функции</translation>
    </message>
    <message>
        <location filename="../src/qtransport.h" line="251"/>
        <source>Unable to save settings</source>
        <translation>Не удалось сохранить настройки</translation>
    </message>
    <message>
        <location filename="../src/qtransport.h" line="252"/>
        <source>Authorization problem</source>
        <translation>Проблема авторизации</translation>
    </message>
    <message>
        <location filename="../src/qtransport.h" line="253"/>
        <source>Authorization canceled</source>
        <translation>Авторизация прервана</translation>
    </message>
    <message>
        <location filename="../src/qtransport.h" line="254"/>
        <source>Unable to perform request</source>
        <translation>Невозможно выполнить запрос</translation>
    </message>
    <message>
        <location filename="../src/qtransport.h" line="255"/>
        <source>Server busy</source>
        <translation>Сервер занят</translation>
    </message>
    <message>
        <location filename="../src/qtransport.h" line="256"/>
        <source>One of the parameters missing or invalid</source>
        <translation>Один из параметров пропущен или неверен</translation>
    </message>
    <message>
        <location filename="../src/qtransport.h" line="257"/>
        <source>Captcha</source>
        <translation>Требуется ввод каптчи</translation>
    </message>
    <message>
        <location filename="../src/qtransport.h" line="258"/>
        <source>Bad response from server</source>
        <translation>Некорректный ответ от сервера</translation>
    </message>
    <message>
        <location filename="../src/qtransport.h" line="259"/>
        <source>Network problem</source>
        <translation>Проблема соединения с сервером</translation>
    </message>
    <message>
        <location filename="../src/qtransport.h" line="260"/>
        <source>Empty message</source>
        <translation>Пустое сообщение</translation>
    </message>
    <message>
        <location filename="../src/qtransport.h" line="261"/>
        <source>Operation prohibited by privacy</source>
        <translation>Операция запрещена приватностью</translation>
    </message>
    <message>
        <location filename="../src/qtransport.h" line="262"/>
        <source>Internal Server Error</source>
        <translation>Внутренняя ошибка сервера</translation>
    </message>
    <message>
        <location filename="../src/qtransport.h" line="263"/>
        <source>Can&apos;t save file</source>
        <translation>Не удалось сохранить файл</translation>
    </message>
    <message>
        <location filename="../src/qtransport.h" line="264"/>
        <source>male</source>
        <translation>мужской</translation>
    </message>
    <message>
        <location filename="../src/qtransport.h" line="265"/>
        <source>female</source>
        <translation>женский</translation>
    </message>
    <message>
        <location filename="../src/qtransport.h" line="268"/>
        <source>Incorrect signature</source>
        <translation>Информация об авторизации неверная или устарела</translation>
    </message>
</context>
<context>
    <name>ServiceFilter</name>
    <message>
        <source>All</source>
        <translation type="obsolete">Все</translation>
    </message>
</context>
<context>
    <name>ServiceMgr</name>
    <message>
        <location filename="../src/servicemgr.cpp" line="897"/>
        <source>During request </source>
        <translation>В ходе запроса </translation>
    </message>
    <message>
        <location filename="../src/servicemgr.cpp" line="912"/>
        <source>&quot;Update list of friends&quot;</source>
        <translation>&quot;Обновление списка друзей&quot;</translation>
    </message>
    <message>
        <location filename="../src/servicemgr.cpp" line="915"/>
        <source>&quot;Delete friend from list&quot;</source>
        <translation>&quot;Удаление друга из списка&quot;</translation>
    </message>
    <message>
        <location filename="../src/servicemgr.cpp" line="921"/>
        <source>&quot;Update list of albums&quot;</source>
        <translation>&quot;Обновление списка альбомов&quot;</translation>
    </message>
    <message>
        <location filename="../src/servicemgr.cpp" line="927"/>
        <source>&quot;Update list of images&quot;</source>
        <translation>&quot;Обновление списка изображений&quot;</translation>
    </message>
    <message>
        <location filename="../src/servicemgr.cpp" line="930"/>
        <source>&quot;Update user profile&quot;</source>
        <translation>&quot;Обновление профиля пользователя&quot;</translation>
    </message>
    <message>
        <location filename="../src/servicemgr.cpp" line="931"/>
        <source>Account swiched to offline mode. Please check network settings and try again.</source>
        <translation>Учетная запись переключена в автономный режим. Пожалуйста, проверьте настройки соединения и попробуйте снова.</translation>
    </message>
    <message>
        <location filename="../src/servicemgr.cpp" line="934"/>
        <source>&quot;Get settings&quot;</source>
        <translation>&quot;Получение настроек&quot;</translation>
    </message>
    <message>
        <location filename="../src/servicemgr.cpp" line="937"/>
        <source>&quot;Set settings&quot;</source>
        <translation>&quot;Применение настроек&quot;</translation>
    </message>
    <message>
        <location filename="../src/servicemgr.cpp" line="943"/>
        <source>&quot;Download image&quot;</source>
        <translation>&quot;Получение изображения&quot;</translation>
    </message>
    <message>
        <location filename="../src/servicemgr.cpp" line="946"/>
        <source>&quot;Upload image&quot;</source>
        <translation>&quot;Загрузка изображения на сервис&quot;</translation>
    </message>
    <message>
        <location filename="../src/servicemgr.cpp" line="948"/>
        <source>&quot;Get comments&quot;</source>
        <translation>&quot;Получение комментариев&quot;</translation>
    </message>
    <message>
        <location filename="../src/servicemgr.cpp" line="951"/>
        <source>&quot;Send comment&quot;</source>
        <translation>&quot;Отправка комментария&quot;</translation>
    </message>
    <message>
        <location filename="../src/servicemgr.cpp" line="954"/>
        <source>&quot;Get list of messages&quot;</source>
        <translation>&quot;Получение сообщений&quot;</translation>
    </message>
    <message>
        <source>&quot;Get message inbox&quot;</source>
        <translation type="obsolete">&quot;Получение списка входящих сообщений&quot;</translation>
    </message>
    <message>
        <source>&quot;Get message outbox&quot;</source>
        <translation type="obsolete">&quot;Получение списка отправленных сообщений&quot;</translation>
    </message>
    <message>
        <location filename="../src/servicemgr.cpp" line="957"/>
        <source>&quot;Send message&quot;</source>
        <translation>&quot;Отправка сообщения&quot;</translation>
    </message>
    <message>
        <location filename="../src/servicemgr.cpp" line="960"/>
        <source>&quot;Mark message as read&quot;</source>
        <translation>&quot;Пометка сообщения прочитанным&quot;</translation>
    </message>
    <message>
        <location filename="../src/servicemgr.cpp" line="963"/>
        <source>&quot;Delete message&quot;</source>
        <translation>&quot;Удаление сообщения&quot;</translation>
    </message>
    <message>
        <location filename="../src/servicemgr.cpp" line="966"/>
        <source>&quot;Get list of registered methods&quot;</source>
        <translation>&quot;Получение списка поддерживаемых методов&quot;</translation>
    </message>
    <message>
        <location filename="../src/servicemgr.cpp" line="969"/>
        <source>&quot;Get feed&quot;</source>
        <translation>Получение новостей</translation>
    </message>
    <message>
        <location filename="../src/servicemgr.cpp" line="976"/>
        <source> from account &quot;%1&quot; the error %2 was caused: </source>
        <translation> от учетной записи &quot;%1&quot; получена ошибка %2: </translation>
    </message>
</context>
<context>
    <name>UIAccountSettings</name>
    <message>
        <location filename="../src/widgets/uiaccountsettings.ui" line="20"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../src/widgets/uiaccountsettings.ui" line="42"/>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <location filename="../src/widgets/uiaccountsettings.ui" line="52"/>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../src/widgets/uiaccountsettings.ui" line="62"/>
        <source>Reconnect</source>
        <translation>Переподключиться</translation>
    </message>
    <message>
        <location filename="../src/widgets/uiaccountsettings.cpp" line="37"/>
        <source> (offline mode)</source>
        <translation> (автономный режим)</translation>
    </message>
</context>
<context>
    <name>UIAddAccount</name>
    <message>
        <location filename="../src/widgets/uiaddaccount.ui" line="20"/>
        <source>Add new account</source>
        <translation>Добавление новой учетной записи</translation>
    </message>
    <message>
        <location filename="../src/widgets/uiaddaccount.ui" line="51"/>
        <source>Account name:</source>
        <translation>Название учетной записи:</translation>
    </message>
    <message>
        <location filename="../src/widgets/uiaddaccount.cpp" line="22"/>
        <source>Input account name and select one of services</source>
        <translation>Введите имя учетной записи и выберите один из сервисов</translation>
    </message>
    <message>
        <location filename="../src/widgets/uiaddaccount.cpp" line="34"/>
        <source>Input name of service!</source>
        <translation>Введите имя учетной записи!</translation>
    </message>
    <message>
        <location filename="../src/widgets/uiaddaccount.cpp" line="40"/>
        <source>This account name already exists!</source>
        <translation>Такое имя учетной записи уже существует!</translation>
    </message>
    <message>
        <location filename="../src/widgets/uiaddaccount.cpp" line="46"/>
        <source>Select one of services!</source>
        <translation>Выберите один из сервисов!</translation>
    </message>
</context>
<context>
    <name>UINetworkSettings</name>
    <message>
        <location filename="../src/widgets/uinetworksettings.ui" line="20"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../src/widgets/uinetworksettings.ui" line="39"/>
        <source>Proxy:</source>
        <translation>Прокси:</translation>
    </message>
    <message>
        <location filename="../src/widgets/uinetworksettings.ui" line="49"/>
        <source>No Proxy</source>
        <translation>Без прокси</translation>
    </message>
    <message>
        <location filename="../src/widgets/uinetworksettings.ui" line="65"/>
        <source>System</source>
        <translation>Системный</translation>
    </message>
    <message>
        <location filename="../src/widgets/uinetworksettings.ui" line="72"/>
        <source>Manual</source>
        <translation>Вручную</translation>
    </message>
    <message>
        <location filename="../src/widgets/uinetworksettings.ui" line="128"/>
        <source>Address:</source>
        <translation>Адрес:</translation>
    </message>
    <message>
        <location filename="../src/widgets/uinetworksettings.ui" line="144"/>
        <source>Port:</source>
        <translation>Порт:</translation>
    </message>
</context>
<context>
    <name>uihelp</name>
    <message>
        <location filename="../src/widgets/uihelp.ui" line="14"/>
        <source>VKGallery - Help</source>
        <translation>VKGallery - Справка</translation>
    </message>
    <message>
        <location filename="../src/widgets/uihelp.ui" line="28"/>
        <source>file:///</source>
        <translation></translation>
    </message>
    <message>
        <source>/help.html</source>
        <translation type="obsolete">/help_ru.html</translation>
    </message>
    <message>
        <source>/about.html</source>
        <translation type="obsolete">/about_ru.html</translation>
    </message>
</context>
</TS>
